@@ -3,7 +3,9 @@ package Padre::Plugin::Nopaste;
 use v5.10;
 use strictures 1;
 
-our $VERSION = '0.07';
+# use strict;
+# use warnings;
+our $VERSION = '0.40';
 
 use Try::Tiny;
 use Padre::Unload ();
@@ -13,11 +15,16 @@ use parent qw{
 	Padre::Role::Task
 };
 use Padre::Plugin::Nopaste::Services;
-use Carp;
+use Carp::Always;
 
 # Turn on $OUTPUT_AUTOFLUSH
 local $| = 1;
 
+use Data::Printer {
+	caller_info => 1,
+	colored     => 1,
+};
+
 
 # Child modules we need to unload when disabled
 use constant CHILDREN => qw{
@@ -66,8 +73,6 @@ sub plugin_enable {
 	# Tests for externals used by Preference's
 	if ( $config->identity_nickname ) {
 		$nick = 1;
-	} else {
-		croak "\nYou need to set 'identity_nickname' \n Look in Tools -> Preferences -> Advance\n\n";
 	}
 
 	#Set/ReSet Config data
@@ -337,17 +342,14 @@ sub event_on_context_menu {
 1;
 __END__
 
-=pod
-
-=encoding utf8
 
 =head1 NAME
 
-Padre::Plugin::Nopaste - NoPaste plugin for Padre, The Perl IDE.
+Padre::Plugin::Nopaste - Padre, The Perl IDE.
 
 =head1 VERSION
 
-version: 0.07
+version  0.40
 
 =head1 SYNOPSIS
 
@@ -447,11 +449,11 @@ You can also look for information on this module at:
 
 L<http://padre.perlide.org/trac/wiki/PadrePluginNopaste>
 
-=item * Our svn repository
+=item * Our svn repository 
 
-L<http://svn.perlide.org/padre/trunk/Padre-Plugin-Nopaste>,
- and can be browsed at
-  L<http://padre.perlide.org/browser/trunk/Padre-Plugin-Nopaste>.
+L<http://svn.perlide.org/padre/trunk/Padre-Plugin-Nopaste>, 
+and can be browsed at 
+L<http://padre.perlide.org/browser/trunk/Padre-Plugin-Nopaste>.
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -470,24 +472,17 @@ Kevin Dawson E<lt>bowtie@cpan.orgE<gt>
 
 Jerome Quelin, E<lt>jquelin@cpan.orgE<gt>
 
-=head2 CONTRIBUTORS
-
-Ahmad M. Zawawi E<lt>ahmad.zawawi@gmail.comE<gt>
-
-Alexandr Ciornii E<lt>alexchorny@gmail.comE<gt>
-
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright E<copy> 2013 the Padre::Plugin::Nopaste L</AUTHOR> and L</CONTRIBUTORS>
- as listed above.
+Copyright (c) 2009 Jerome Quelin, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify
- it under the same terms as Perl itself.
+it under the same terms as Perl itself.
 
 =cut
 
-# Copyright 2008-2013 The Padre development team as listed in Padre.pm.
+# Copyright 2008-2012 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl 5 itself.
